@@ -5,10 +5,11 @@
 //    (See accompanying file LICENSE_1_0.txt or copy at
 //          http://www.boost.org/LICENSE_1_0.txt)
 
-// See http://www.boost.org for updates, documentation, and revision history.
+// See http://www.boost.org for updates, documentation, and revision history of C++ code..
 
-// Ported from C++ boost 1.75.0 to Rust in 2020/2021 by Eadf (github.com/eadf)
+// Ported from C++ boost 1.76.0 to Rust in 2020/2021 by Eadf (github.com/eadf)
 
+//! Utilities for extended float. Supports 63 bit mantissa with 32 bit exponent.
 use super::extended_int as EI;
 use num::{Float, NumCast};
 use std::fmt;
@@ -176,36 +177,14 @@ impl ExtendedExponentFpt<f64> {
     /// ```
     #[inline]
     pub fn sqrt(&self) -> Self {
-        #[cfg(feature = "console_debug_eval")]
-        {
-            println!(
-                "->sqrt:{:.12} val:{:.12} exp:{:}",
-                self.d(),
-                self.val(),
-                self.exp()
-            );
-        }
         let mut val = self.val_;
         let mut exp = self.exp_;
         if (exp & 1) != 0 {
             val *= 2.0;
             exp -= 1;
         }
-        #[cfg(feature = "console_debug_eval")]
-        {
-            let rv = Self::new2(val.sqrt(), exp >> 1);
-            println!(
-                "<-sqrt:{:.12} val:{:.12} exp:{:}",
-                rv.d(),
-                rv.val(),
-                rv.exp()
-            );
-            rv
-        }
-        #[cfg(not(feature = "console_debug_eval"))]
-        {
-            Self::new2(val.sqrt(), exp >> 1)
-        }
+
+        Self::new2(val.sqrt(), exp >> 1)
     }
 
     /// A to-float operation.
