@@ -5,51 +5,17 @@
 //    (See accompanying file LICENSE_1_0.txt or copy at
 //          http://www.boost.org/LICENSE_1_0.txt)
 
-// See http://www.boost.org for updates, documentation, and revision history.
+// See http://www.boost.org for updates, documentation, and revision history of C++ code.
 
-// Ported from C++ boost 1.75.0 to Rust in 2020/2021 by Eadf (github.com/eadf)
+// Ported from C++ boost 1.76.0 to Rust in 2020/2021 by Eadf (github.com/eadf)
 
-//! Geometry predicates with floating-point variables usually require
-//! high-precision predicates to retrieve the correct result.
-//! Epsilon robust predicates give the result within some epsilon relative
-//! error, but are a lot faster than high-precision predicates.
-//! To make algorithm robust and efficient epsilon robust predicates are
-//! used at the first step. In case of the undefined result high-precision
-//! arithmetic is used to produce required robustness. This approach
-//! requires exact computation of epsilon intervals within which epsilon
-//! robust predicates have undefined value.
-//! There are two ways to measure an error of floating-point calculations:
-//! relative error and ULPs (units in the last place).
-//! Let EPS be machine epsilon, then next inequalities have place:
-//! 1 EPS <= 1 ULP <= 2 EPS (1), 0.5 ULP <= 1 EPS <= 1 ULP (2).
-//! ULPs are good for measuring rounding errors and comparing values.
-//! Relative errors are good for computation of general relative
-//! error of formulas or expressions. So to calculate epsilon
-//! interval within which epsilon robust predicates have undefined result
-//! next schema is used:
-//!     1) Compute rounding errors of initial variables using ULPs;
-//!     2) Transform ULPs to epsilons using upper bound of the (1);
-//!     3) Compute relative error of the formula using epsilon arithmetic;
-//!     4) Transform epsilon to ULPs using upper bound of the (2);
-//! In case two values are inside undefined ULP range use high-precision
-//! arithmetic to produce the correct result, else output the result.
-//! Look at almost_equal function to see how two floating-point variables
-//! are checked to fit in the ULP range.
-//! If A has relative error of r(A) and B has relative error of r(B) then:
-//!     1) r(A + B) <= max(r(A), r(B)), for A * B >= 0;
-//!     2) r(A - B) <= B*r(A)+A*r(B)/(A-B), for A * B >= 0;
-//!     2) r(A * B) <= r(A) + r(B);
-//!     3) r(A / B) <= r(A) + r(B);
-//! In addition rounding error should be added, that is always equal to
-//! 0.5 ULP or at most 1 epsilon. As you might see from the above formulas
-//! subtraction relative error may be extremely large, that's why
-//! epsilon robust comparator class is used to store floating point values
-//! and compute subtraction as the final step of the evaluation.
-//! For further information about relative errors and ULPs try this link:
-//! http://docs.sun.com/source/806-3568/ncg_goldberg.html
-//!
+//! Module containing robust floating points utilities.
+
+#[cfg(test)]
 mod extendedint_tests;
+#[cfg(test)]
 mod robustdif_tests;
+#[cfg(test)]
 mod robustfpt_tests;
 
 use super::extended_exp_fpt as EX;
@@ -79,6 +45,45 @@ fn is_neg_f(fpv: f64) -> bool {
     fpv < 0_f64
 }
 
+/// Geometry predicates with floating-point variables usually require
+/// high-precision predicates to retrieve the correct result.
+/// Epsilon robust predicates give the result within some epsilon relative
+/// error, but are a lot faster than high-precision predicates.
+/// To make algorithm robust and efficient epsilon robust predicates are
+/// used at the first step. In case of the undefined result high-precision
+/// arithmetic is used to produce required robustness. This approach
+/// requires exact computation of epsilon intervals within which epsilon
+/// robust predicates have undefined value.
+/// There are two ways to measure an error of floating-point calculations:
+/// relative error and ULPs (units in the last place).
+/// Let EPS be machine epsilon, then next inequalities have place:
+/// 1 EPS <= 1 ULP <= 2 EPS (1), 0.5 ULP <= 1 EPS <= 1 ULP (2).
+/// ULPs are good for measuring rounding errors and comparing values.
+/// Relative errors are good for computation of general relative
+/// error of formulas or expressions. So to calculate epsilon
+/// interval within which epsilon robust predicates have undefined result
+/// next schema is used:
+///     1) Compute rounding errors of initial variables using ULPs;
+///     2) Transform ULPs to epsilons using upper bound of the (1);
+///     3) Compute relative error of the formula using epsilon arithmetic;
+///     4) Transform epsilon to ULPs using upper bound of the (2);
+/// In case two values are inside undefined ULP range use high-precision
+/// arithmetic to produce the correct result, else output the result.
+/// Look at almost_equal function to see how two floating-point variables
+/// are checked to fit in the ULP range.
+/// If A has relative error of r(A) and B has relative error of r(B) then:
+///     1) r(A + B) <= max(r(A), r(B)), for A * B >= 0;
+///     2) r(A - B) <= B*r(A)+A*r(B)/(A-B), for A * B >= 0;
+///     2) r(A * B) <= r(A) + r(B);
+///     3) r(A / B) <= r(A) + r(B);
+/// In addition rounding error should be added, that is always equal to
+/// 0.5 ULP or at most 1 epsilon. As you might see from the above formulas
+/// subtraction relative error may be extremely large, that's why
+/// epsilon robust comparator class is used to store floating point values
+/// and compute subtraction as the final step of the evaluation.
+/// For further information about relative errors and ULPs try this link:
+/// <http://docs.sun.com/source/806-3568/ncg_goldberg.html>
+///
 #[derive(Copy, Clone)]
 pub struct RobustFpt {
     fpv_: f64,
@@ -184,8 +189,7 @@ impl RobustFpt {
             //fpv_: Self::get_sqrt(self.fpv_),
             fpv_: self.fpv_.sqrt(),
             // self.re_ * 0.5 + ROUNDING_ERROR
-            re_: self.re_ * OrderedFloat(num::cast::<f32, f64>(0.5f32).unwrap())
-                + OrderedFloat(ROUNDING_ERROR),
+            re_: self.re_ * OrderedFloat(0.5f64) + OrderedFloat(ROUNDING_ERROR),
         }
     }
 }
@@ -231,6 +235,12 @@ impl ops::Add<RobustFpt> for RobustFpt {
 
 impl ops::AddAssign<RobustFpt> for RobustFpt {
     fn add_assign(&mut self, _rhs: RobustFpt) {
+        #[cfg(feature = "console_debug")]
+        {
+            assert!(self.fpv_.is_finite());
+            assert!(_rhs.fpv_.is_finite());
+        }
+
         let fpv: f64 = self.fpv_ + _rhs.fpv_;
         let re = if (!self.is_neg() && !_rhs.is_neg()) || (!self.is_pos() && !_rhs.is_pos()) {
             std::cmp::max(self.re_, _rhs.re_) + OrderedFloat(ROUNDING_ERROR)
@@ -247,10 +257,7 @@ impl ops::AddAssign<RobustFpt> for RobustFpt {
         self.fpv_ = fpv;
         self.re_ = re;
         #[cfg(feature = "console_debug")]
-        {
-            assert!(self.fpv_.is_finite());
-            assert!(!self.re_.is_nan());
-        }
+        assert!(self.fpv_.is_finite());
     }
 }
 
@@ -477,7 +484,6 @@ impl RobustDif {
     pub fn new_2(pos: f64, neg: f64) -> Self {
         #[cfg(feature = "console_debug")]
         {
-            // todo: remove asserts when stable
             assert!(!pos.is_sign_negative());
             assert!(!neg.is_sign_negative());
         }
@@ -567,6 +573,11 @@ impl ops::SubAssign<RobustDif> for RobustDif {
 
 impl ops::SubAssign<RobustFpt> for RobustDif {
     fn sub_assign(&mut self, _rhs: RobustFpt) {
+        #[cfg(feature = "console_debug")]
+        {
+            assert!(self.dif().fpv().is_finite());
+            assert!(_rhs.fpv().is_finite());
+        }
         //dbg!(&self, &_rhs);
         if !_rhs.is_neg() {
             self.negative_sum_ += _rhs;
@@ -686,13 +697,13 @@ impl ops::DivAssign<RobustFpt> for RobustDif {
 
 /// Used to compute expressions that operate with sqrts with predefined
 /// relative error. Evaluates expressions of the next type:
-/// sum(i = 1 .. n)(A[i] * sqrt(B[i])), 1 <= n <= 4.
+/// sum(i = 1 .. n)(A\[i\] * sqrt(B\[i\])), 1 <= n <= 4.
 #[allow(non_camel_case_types)]
 pub struct robust_sqrt_expr<
     _fpt: NumCast + Float + fmt::Display + Default + fmt::Debug + ops::Neg<Output = _fpt>,
 > {
     #[doc(hidden)]
-    _pdf: PhantomData<_fpt>,
+    pdf_: PhantomData<_fpt>,
 }
 
 #[allow(non_camel_case_types)]
@@ -701,7 +712,7 @@ impl<
     > Default for robust_sqrt_expr<_fpt>
 {
     fn default() -> Self {
-        Self { _pdf: PhantomData }
+        Self { pdf_: PhantomData }
     }
 }
 
@@ -716,7 +727,7 @@ impl<
     }
 
     /// Evaluates expression (re = 4 EPS):
-    /// A[0] * sqrt(B[0]).
+    /// A\[0\] * sqrt(B\[0\]).
     pub fn eval1(
         &self,
         a: &[EI::ExtendedInt],
@@ -727,16 +738,7 @@ impl<
         //tln!("eval1:");
         //tln!(" a:{:.0}", a.d());
         //tln!(" b:{:.0}", b.d());
-        #[cfg(feature = "console_debug_eval")]
-        {
-            let rv = a * (b.sqrt());
-            tln!("eval1: {:.0}", rv.d());
-            rv
-        }
-        #[cfg(not(feature = "console_debug_eval"))]
-        {
-            a * (b.sqrt())
-        }
+        a * (b.sqrt())
     }
 
     // Evaluates expression (re = 7 EPS):
@@ -748,16 +750,7 @@ impl<
     ) -> EX::ExtendedExponentFpt<f64> {
         let ra = self.eval1(a, b);
         let rb = self.eval1(&a[1..], &b[1..]);
-        #[cfg(feature = "console_debug_eval")]
-        {
-            tln!("->eval2");
-            tln!(" a[0]:{:.0}", a[0].d());
-            tln!(" a[1]:{:.0}", a[1].d());
-            tln!(" b[0]:{:.0}", b[0].d());
-            tln!(" b[1]:{:.0}", b[1].d());
-            tln!(" ra:{:.0}", ra.d());
-            tln!(" rb:{:.0}", rb.d());
-        }
+
         if ra.is_zero()
             || rb.is_zero()
             || (!ra.is_neg() && !rb.is_neg())
@@ -769,25 +762,12 @@ impl<
         let p = &a[0] * &a[0] * &b[0] - &a[1] * &a[1] * &b[1];
         let numer = Self::i_to_f(&p);
         let divisor = ra - rb;
-        #[cfg(feature = "console_debug_eval")]
-        {
-            let rv = numer / divisor;
-            tln!(
-                "<-eval2:\n numer:{:.0}\n divisor:{:.0}\n rv:{:.0}",
-                numer.d(),
-                divisor.d(),
-                rv.d()
-            );
-            rv
-        }
-        #[cfg(not(feature = "console_debug_eval"))]
-        {
-            numer / divisor
-        }
+
+        numer / divisor
     }
 
     /// Evaluates expression (re = 16 EPS):
-    /// A[0] * sqrt(B[0]) + A[1] * sqrt(B[1]) + A[2] * sqrt(B[2]).
+    /// A\[0\] * sqrt(B\[0\]) + A\[1\] * sqrt(B\[1\]) + A\[2\] * sqrt(B\[2\]).
     pub fn eval3(
         &self,
         a: &[EI::ExtendedInt],
@@ -795,18 +775,7 @@ impl<
     ) -> EX::ExtendedExponentFpt<f64> {
         let ra = self.eval2(a, b);
         let rb = self.eval1(&a[2..], &b[2..]);
-        #[cfg(feature = "console_debug_eval")]
-        {
-            tln!("->eval3");
-            tln!(" a[0]:{:.0}", a[0].d());
-            tln!(" a[1]:{:.0}", a[1].d());
-            tln!(" a[2]:{:.0}", a[2].d());
-            tln!(" b[0]:{:.0}", b[0].d());
-            tln!(" b[1]:{:.0}", b[1].d());
-            tln!(" b[2]:{:.0}", b[2].d());
-            tln!(" ra:{:.0}", ra.d());
-            tln!(" rb:{:.0}", rb.d());
-        }
+
         if ra.is_zero()
             || rb.is_zero()
             || (!ra.is_neg() && !rb.is_neg())
@@ -821,42 +790,15 @@ impl<
         tb[0] = EI::ExtendedInt::from(1);
         ta[1] = &a[0] * &a[1] * &EI::ExtendedInt::from(2_i32);
         tb[1] = &b[0] * &b[1];
-        #[cfg(feature = "console_debug_eval")]
-        {
-            tln!("<-eval3");
-            tln!(" ta[0]:{:.0}", ta[0].d());
-            tln!(" ta[1]:{:.0}", ta[1].d());
-            tln!(" tb[0]:{:.0}", tb[0].d());
-            tln!(" tb[1]:{:.0}", tb[1].d());
-            tln!(" ra:{:.0} val:{:.12} exp:{:}", ra.d(), ra.val(), ra.exp());
-            tln!(" rb:{:.0} val:{:.12} exp:{:}", rb.d(), rb.val(), rb.exp());
-            let rarb = ra - rb;
-            tln!(
-                " ra-rb:{:.0} val:{:.12} exp:{:}",
-                rarb.d(),
-                rarb.val(),
-                rarb.exp()
-            );
-        }
+
         let nom = self.eval2(&ta[..], &tb[..]);
         let div = ra - rb;
-        #[cfg(feature = "console_debug_eval")]
-        {
-            let rv = nom / div;
-            tln!(" nom:{:.0}", nom.d());
-            tln!(" div:{:.0}", div.d());
-            tln!(" rv:{:.0}", rv.d());
-            rv
-        }
-        #[cfg(not(feature = "console_debug_eval"))]
-        {
-            nom / div
-        }
+        nom / div
     }
 
     /// Evaluates expression (re = 25 EPS):
-    /// A[0] * sqrt(B[0]) + A[1] * sqrt(B[1]) +
-    /// A[2] * sqrt(B[2]) + A[3] * sqrt(B[3]).
+    /// A\[0\] * sqrt(B\[0\]) + A\[1\] * sqrt(B\[1\]) +
+    /// A\[2\] * sqrt(B\[2\]) + A\[3\] * sqrt(B\[3\]).
     pub fn eval4(
         &self,
         a: &[EI::ExtendedInt],
@@ -891,21 +833,12 @@ impl<
         tb[1] = &b[0] * &b[1];
         ta[2] = &a[2] * &a[3] * &EI::ExtendedInt::from(-2_i32);
         tb[2] = &b[2] * &b[3];
-        #[cfg(feature = "console_debug_eval")]
-        {
-            let rv = self.eval3(&ta, &tb) / (ra - rb);
-            tln!("<-eval4:{}", rv.d());
-            rv
-        }
-        #[cfg(not(feature = "console_debug_eval"))]
-        {
-            self.eval3(&ta, &tb) / (ra - rb)
-        }
+        self.eval3(&ta, &tb) / (ra - rb)
     }
 
-    /// Evaluates A[0] * sqrt(B[0]) + A[1] * sqrt(B[1]) +
-    ///           A[2] + A[3] * sqrt(B[0] * B[1]).
-    /// B[3] = B[0] * B[1].
+    /// Evaluates A\[0] * sqrt(B\[0\]) + A\[1\] * sqrt(B\[1\]) +
+    ///           A\[2] + A\[3\] * sqrt(B\[0\] * B\[1\]).
+    /// B\[3\] = B\[0\] * B\[1\].
     #[allow(non_snake_case)]
     pub fn sqrt_expr_evaluator_pss3(
         &mut self,
@@ -917,23 +850,12 @@ impl<
 
         let lh = self.eval2(A, B);
         let rh = self.eval2(&A[2..], &B[2..]);
-        #[cfg(feature = "console_debug_eval")]
-        {
-            tln!(
-                "sqrt_expr_evaluator_pss3\n lh={:.0}\n rh={:.0}",
-                lh.d(),
-                rh.d()
-            );
-        }
+
         if lh.is_zero()
             || rh.is_zero()
             || (!lh.is_neg() && !rh.is_neg())
             || (!lh.is_pos() && !rh.is_pos())
         {
-            #[cfg(feature = "console_debug_eval")]
-            {
-                tln!("<-sqrt_expr_evaluator_pss3 lh + rh");
-            }
             return lh + rh;
         }
         cA[0] = &A[0] * &A[0] * &B[0] + &A[1] * &A[1] * &B[1]
@@ -944,37 +866,17 @@ impl<
         cB[1] = B[3].clone();
         let numer = self.eval2(&cA, &cB);
         let divisor = lh - rh;
-        #[cfg(feature = "console_debug_eval")]
-        {
-            tln!(
-                "<-sqrt_expr_evaluator_pss3\n numer:{:.0}\n divisor:{:.0}",
-                numer.d(),
-                divisor.d()
-            );
-        }
         numer / divisor
     }
 
-    /// Evaluates A[3] + A[0] * sqrt(B[0]) + A[1] * sqrt(B[1]) +
-    ///           A[2] * sqrt(B[3] * (sqrt(B[0] * B[1]) + B[2])).
+    /// Evaluates A\[3\] + A\[0\] * sqrt(B\[0\]) + A\[1\] * sqrt(B\[1\]) +
+    ///           A\[2\] * sqrt(B\[3\] * (sqrt(B\[0\] * B\[1\]) + B\[2\])).
     #[allow(non_snake_case)]
     pub fn sqrt_expr_evaluator_pss4(
         &mut self,
         A: &[EI::ExtendedInt],
         B: &[EI::ExtendedInt],
     ) -> EX::ExtendedExponentFpt<f64> {
-        #[cfg(feature = "console_debug_eval")]
-        {
-            tln!("->sqrt_expr_evaluator_pss4");
-            tln!(" A[0]={:?}", A[0]);
-            tln!(" A[1]={:?}", A[1]);
-            tln!(" A[2]={:?}", A[2]);
-            tln!(" A[3]={:?}", A[3]);
-            tln!(" B[0]={:?}", B[0]);
-            tln!(" B[1]={:?}", B[1]);
-            tln!(" B[2]={:?}", B[2]);
-            tln!(" B[3]={:?}", B[3]);
-        }
         let mut cA: [EI::ExtendedInt; 4] = [
             EI::ExtendedInt::zero(),
             EI::ExtendedInt::zero(),
@@ -999,14 +901,6 @@ impl<
                 || (!lh.is_neg() && !rh.is_neg())
                 || (!lh.is_pos() && !rh.is_pos())
             {
-                #[cfg(feature = "console_debug_eval")]
-                {
-                    tln!(
-                        "<-sqrt_expr_evaluator_pss4 1\nlh:{:.0}\nrh:{:.0}",
-                        lh.d(),
-                        rh.d()
-                    );
-                }
                 return lh + rh;
             }
             cA[0] = &A[0] * &A[0] * &B[0] + &A[1] * &A[1] * &B[1] - &A[2] * &A[2] * &B[3] * &B[2];
@@ -1014,15 +908,6 @@ impl<
             cA[1] = &A[0] * &A[1] * &EI::ExtendedInt::from(2_i32) - &A[2] * &A[2] * &B[3];
             cB[1] = &B[0] * &B[1];
             let numer = self.eval2(&cA, &cB);
-            #[cfg(feature = "console_debug_eval")]
-            {
-                tln!(
-                    "<-sqrt_expr_evaluator_pss4 2\nnumerator:{:.0}\nlh:{:.0}\nrh:{:.0}",
-                    numer.d(),
-                    lh.d(),
-                    rh.d()
-                );
-            }
 
             return numer / (lh - rh);
         }
@@ -1038,34 +923,12 @@ impl<
         cA[2] = A[3].clone();
         cB[2] = EI::ExtendedInt::from(1);
         let lh = self.eval3(&cA, &cB);
-        #[cfg(feature = "console_debug_eval")]
-        {
-            tln!(
-                "<-sqrt_expr_evaluator_pss4 2.5\nlh:{:.0}\nrh:{:.0}",
-                lh.d(),
-                rh.d()
-            );
-            tln!("lh.is_neg():{} lh.is_pos():{}", lh.is_neg(), lh.is_pos());
-            tln!("rh.is_neg():{} rh.is_pos():{}", rh.is_neg(), rh.is_pos());
-            tln!(
-                "lh.is_zero():{} rh.is_zero():{}",
-                lh.is_zero(),
-                rh.is_zero()
-            );
-        }
+
         if lh.is_zero()
             || rh.is_zero()
             || (!lh.is_neg() && !rh.is_neg())
             || (!lh.is_pos() && !rh.is_pos())
         {
-            #[cfg(feature = "console_debug_eval")]
-            {
-                tln!(
-                    "<-sqrt_expr_evaluator_pss4 3\nlh:{:.0}\nrh:{:.0}",
-                    lh.d(),
-                    rh.d()
-                );
-            }
             return lh + rh;
         }
         cA[0] = &A[3] * &A[0] * &EI::ExtendedInt::from(2_i32);
@@ -1075,15 +938,6 @@ impl<
         cA[3] = &A[0] * &A[1] * &EI::ExtendedInt::from(2_i32) - &A[2] * &A[2] * &B[3];
         cB[3] = &B[0] * &B[1];
         let numer = self.sqrt_expr_evaluator_pss3(&cA, &cB);
-        #[cfg(feature = "console_debug_eval")]
-        {
-            tln!(
-                "<-sqrt_expr_evaluator_pss4 4\nnumer:{:.0}\nlh:{:.0}\nrh:{:.0}",
-                numer.d(),
-                lh.d(),
-                rh.d()
-            );
-        }
 
         numer / (lh - rh)
     }
